==> pydatahub-2.11.1.tar.gz: pydatahub-2.11.1/datahub/models/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from .schema import Field, RecordSchema, FieldType
from .record import RecordType, Record, BlobRecord, TupleRecord, FailedRecord
from .cursor import CursorType
from .compress import CompressFormat
from .shard import ShardState, Shard, ShardContext, ShardBase
from .connector import ConnectorConfig, ConnectorShardStatus, AuthMode, ConnectorState, PartitionMode, \
    OdpsConnectorConfig, DatabaseConnectorConfig, EsConnectorConfig, FcConnectorConfig, OssConnectorConfig, \
    OtsConnectorConfig, ConnectorState, OtsConnectorConfig, ConnectorType
from .subscription import OffsetBase, OffsetWithVersion, OffsetWithSession, SubscriptionState
from .params import *
from .results import *

==> pydatahub-2.17.0.tar.gz: pydatahub-2.17.0/datahub/models/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from .schema import Field, RecordSchema, FieldType
from .record import RecordType, Record, BlobRecord, TupleRecord, FailedRecord
from .cursor import CursorType
from .compress import CompressFormat
from .shard import ShardState, Shard, ShardContext, ShardBase
from .connector import ConnectorConfig, ConnectorShardStatus, AuthMode, ConnectorState, PartitionMode, \
    OdpsConnectorConfig, DatabaseConnectorConfig, EsConnectorConfig, FcConnectorConfig, OssConnectorConfig, \
    OtsConnectorConfig, ConnectorState, OtsConnectorConfig, ConnectorType, ConnectorOffset
from .subscription import OffsetBase, OffsetWithVersion, OffsetWithSession, SubscriptionState
from .params import *
from .results import *
